summaryrefslogtreecommitdiffstats
path: root/source-builder/sb/options.py
diff options
context:
space:
mode:
authorChris Johns <chrisj@rtems.org>2017-03-26 13:19:18 +1100
committerChris Johns <chrisj@rtems.org>2017-03-26 13:19:18 +1100
commitdca7ab285321d788f3f7f419ef8f2f4d3cf77a12 (patch)
tree66b2c156fccb5c8618c1b7a1f5c0b62e41c4290b /source-builder/sb/options.py
parent4.11: ARM: Optimize IEEE-754 sqrt implementation (diff)
downloadrtems-source-builder-dca7ab285321d788f3f7f419ef8f2f4d3cf77a12.tar.bz2
sb: Add the `release_path` key to the `version` section in the VERSION file.
A release can specify a custom releaase URL path. Closes #2952.
Diffstat (limited to 'source-builder/sb/options.py')
-rw-r--r--source-builder/sb/options.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/source-builder/sb/options.py b/source-builder/sb/options.py
index 7791329..089d5a7 100644
--- a/source-builder/sb/options.py
+++ b/source-builder/sb/options.py
@@ -641,9 +641,9 @@ def load(args, optargs = None, defaults = '%{_sbdir}/defaults.mc'):
o.post_process()
#
# Load the release hashes
#
- version.load_release_hashes(o.defaults)
+ version.load_release_settings(o.defaults)
return o
@@ -641,9 +641,9 @@ def load(args, optargs = None, defaults = '%{_sbdir}/defaults.mc'):
o.post_process()
#
- # Load the release hashes
+ # Load the release settings
#